@@ -108,7 +108,9 @@ def timer(
             t1 = dt.now()
             out_fun = fun(*args, **kargs)
             d_out = dt.now()-t1
-            message = dict(dt=d_out if delta_time else d_out.microseconds)
+            message = dict(
+                dt=d_out if delta_time else d_out.total_seconds()*1000
+            )
             if name:
                 message['name'] = (
                     name if isinstance(name, str) else fun.__name__
@@ -129,7 +131,7 @@ def timer_class(
     Décorateur d'une classe. Permet de calculer le temps d'exécution de  
     chaque méthode de la classe. Empackage dans un dictionnaire le 
     nom de la méthode (name) et le temps d'éxécution de la méthode en 
-    micro-seconde (dt).
+    milli-seconde (dt).
 
     Parameters
     ----------
@@ -140,7 +142,7 @@ def timer_class(
     delta_time : bool
         Si True renvoit au format lisible par un humain
         (HH:MM:SS.microsecondes), si False renvoit le temps d'éxécution en 
-        microsecondes.
+        milli-secondes.
     name : Union[bool, str]
         nom de l'identifiant de l'appellant. Si True renvoit le nom de la 
         fonction appelante, si False ne renvoit par le nom, si string 
