@@ -30,9 +30,7 @@ from torch.utils.data.distributed import DistributedSampler
 
 from dstk.pytorch._utils import check_tensor, is_dist_avail_and_initialized
 from dstk.pytorch._callback import (CallbackInterface, CallbackHandler,
-                                    FitState, FitControl, PrintCallback,
-                                    ProgressBarCallback, EarlyStoppingCallback)
-from dstk.pytorch._utils_distrib import is_main_process
+                                    FitState, FitControl)
 from dstk.utils.errors import DivergenceError
 
 
@@ -415,6 +413,8 @@ class BaseEnvironnement(BaseEstimator):
         """
         if list_callbacks:
             list_callbacks.begin_step(self, data, state, control, None)
+        state.n_iter += 1
+        iter_accu = state.n_iter % control.gradient_accumulation == 0
         self.train()
         if control.device.type != "cpu":
             for key, value in data.items():
@@ -434,15 +434,34 @@ class BaseEnvironnement(BaseEstimator):
             loss_ = loss_fn(output, target, **loss_kargs)
         if control.gradient_accumulation > 1:
             loss_ /= control.gradient_accumulation
-        control.grad_scaler.scale(loss_).backward()
-        state.n_iter += 1
-        if state.n_iter % control.gradient_accumulation == 0:
+            if (
+                control.is_distributed
+                and hasattr(self, 'no_sync')
+                and not iter_accu
+            ):
+                with self.no_sync:
+                    control.grad_scaler.scale(loss_).backward()
+            elif (
+                control.is_distributed
+                and not hasattr(self, 'no_sync')
+                and not iter_accu
+            ):
+                warn(
+                    "Instance distribué, mais le modèle ne possède pas de "
+                    "contexte no_sync ce qui est un comportement anormale."
+                )
+                control.grad_scaler.scale(loss_).backward()
+            else:
+                control.grad_scaler.scale(loss_).backward()
+        else:
+            control.grad_scaler.scale(loss_).backward()
+        if iter_accu:
+            self.optimizer.zero_grad()
             if control.max_gradient_norm:
                 control.grad_scaler.unscale_(self.optimizer)
                 clip_grad_norm_(self.parameters(), control.max_gradient_norm)
             control.grad_scaler.step(self.optimizer)
             control.grad_scaler.update()
-            self.optimizer.zero_grad()
         loss = loss_.detach()
         self._divergence(loss)
         if list_callbacks:
@@ -798,14 +817,6 @@ class BaseEnvironnement(BaseEstimator):
                 "comportement non souhaité."
             )
 
-        if (
-            not eval_dataset is None
-            and isinstance(eval_dataset.sampler, DistributedSampler)
-        ):
-            test_eval_prosses = lambda: True
-        else:
-            test_eval_prosses = is_main_process
-
         # Permet de construire le modèle avec les paramètres actuels du fit.
         if build:
             self.build()
@@ -923,13 +934,14 @@ class BaseEnvironnement(BaseEstimator):
         list_callbacks.begin_train(self, dataset, state, control, None)
         try:
             for n_epoch in range(nb_epoch):
-                if is_dist_avail_and_initialized():
-                    dataset.sampler.set_epoch(n_epoch)
+                if control.is_distributed:
+                    if hasattr(dataset.sampler, 'set_epoch'):
+                        dataset.sampler.set_epoch(n_epoch)
                     if (
                         eval_dataset
-                        and isinstance(
+                        and hasattr(
                             eval_dataset.sampler, 
-                            DistributedSampler
+                            'set_epoch'
                         )
                     ):
                         eval_dataset.sampler.set_epoch(n_epoch)
@@ -948,7 +960,7 @@ class BaseEnvironnement(BaseEstimator):
                         eval_dataset
                         and self._mod(state.n_iter, iter_eval) == 0
                     ):
-                        if test_eval_prosses():
+                        if control.is_master:
                             self._iter_eval(
                                 eval_dataset=eval_dataset,
                                 loss_fn=loss_fn,
@@ -959,7 +971,7 @@ class BaseEnvironnement(BaseEstimator):
                             )
                             if control.diverge or control.training_stop:
                                 break
-                        if is_dist_avail_and_initialized():
+                        if control.is_distributed:
                             torch.distributed.barrier()
                     try:
                         loss_step = self._train_step(
