@@ -23,6 +23,8 @@ from tqdm import tqdm
 
 from dstk.utils.meta_interface import SuperclassDocstring
 from dstk.utils.errors import TrainError
+from dstk.pytorch._utils_distrib import is_main_process
+from dstk.pytorch._utils import is_dist_avail_and_initialized
 
 # Permet d'éviter une initialisation circulaire via l'import de
 # BaseEnvironnement
@@ -100,6 +102,8 @@ class FitControl:
     gradient_accumulation: Optional[int] = None
     max_gradient_norm: Optional[float] = None
     expected_key_to_device: List[str] = field(default_factory=list)
+    is_master = is_main_process()
+    is_distributed = is_dist_avail_and_initialized()
 
     def __post_init__(self):
         if (
@@ -1070,7 +1074,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                     )
                     self.old_lr = lr
 
-    def end_step(
+    def begin_step(
         self,
         model: PyTorchEstimators,
         data: List[Dict[str, Tensor]],
